@@ -19,7 +19,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 
 extends 'W3C::SOAP::XSD::Document::Type';
 
-our $VERSION     = version->new('0.02');
+our $VERSION     = version->new('0.03');
 
 has sequence => (
     is      => 'rw',
@@ -72,7 +72,7 @@ sub _extension {
         my ($ns, $tag) = split_ns($node->getAttribute('base'));
         my $ns_uri = $self->document->get_ns_uri($ns, $self->node);
 
-        return $self->document->get_module_base( $ns_uri ) . "::$tag";
+        return $self->document->get_module_name( $ns_uri ) . "::$tag";
     }
 
     return;
@@ -117,7 +117,7 @@ W3C::SOAP::XSD::Document::ComplexType - <One-line description of module's purpos
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document::ComplexType version 0.02.
+This documentation refers to W3C::SOAP::XSD::Document::ComplexType version 0.03.
 
 
 =head1 SYNOPSIS
