@@ -19,7 +19,7 @@ use W3C::SOAP::Utils qw/split_ns xml_error/;
 
 extends 'W3C::SOAP::XSD::Document::Type';
 
-our $VERSION     = version->new('0.02');
+our $VERSION     = version->new('0.03');
 
 has complex_type => (
     is     => 'rw',
@@ -114,7 +114,7 @@ sub _package {
         return "xs:$name";
     }
 
-    my $base = $self->document->get_module_base( $ns_uri || $self->document->target_namespace );
+    my $base = $self->document->get_module_name( $ns_uri || $self->document->target_namespace );
 
     return $base . '::' . $name;
 }
@@ -151,7 +151,7 @@ sub type_module {
     $ns ||= $self->document->ns_name;
     my $ns_uri = $self->document->get_ns_uri($ns, $self->node);
 
-    return $self->simple_type || $self->document->get_module_base( $ns_uri ) . '::' . $type;
+    return $self->simple_type || $self->document->get_module_name( $ns_uri ) . '::' . $type;
 }
 
 sub simple_type {
@@ -274,7 +274,7 @@ W3C::SOAP::XSD::Document::Element - XML Schema Element
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document::Element version 0.02.
+This documentation refers to W3C::SOAP::XSD::Document::Element version 0.03.
 
 
 =head1 SYNOPSIS
