@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
 
 extends 'W3C::SOAP::Parser';
 
-our $VERSION     = version->new('0.02');
+our $VERSION     = version->new('0.03');
 
 subtype xsd_documents =>
     as 'ArrayRef[W3C::SOAP::XSD::Document]';
@@ -103,7 +103,7 @@ sub write_modules {
                 my ($ns) = split_ns($element->type);
                 $ns ||= $element->document->target_namespace;
                 my $ns_uri = $element->document->get_ns_uri($ns, $element->node);
-                $modules{ $type->document->get_module_base($ns_uri) }++
+                $modules{ $type->document->get_module_name($ns_uri) }++
                     if $ns_uri && $ns_uri ne $type->document->target_namespace;
             }
 
@@ -151,7 +151,7 @@ sub write_module {
     my $template = $self->template;
 
      if ($written{$file}++) {
-        warn "Already written $file!\n";
+         #warn "Already written $file!\n";
         return;
     }
 
@@ -160,6 +160,10 @@ sub write_module {
         if $template->error;
 }
 
+sub written_modules {
+    return keys %written;
+}
+
 sub get_schemas {
     my ($self) = @_;
     my @xsds   = @{ $self->document };
@@ -250,9 +254,11 @@ sub dynamic_classes {
 
         # Complex types
         my @complex_types = @{ $xsd->complex_types };
+        my %types;
         while ( my $type = shift @complex_types ) {
             my $type_name = $type->name || $type->parent_node->name;
             my $type_module = $module . '::' . $type_name;
+            next if $types{$type_module}++;
 
             my %modules = ( 'W3C::SOAP::XSD' => 1 );
             for my $el (@{ $type->sequence }) {
@@ -425,7 +431,7 @@ W3C::SOAP::XSD::Parser - Parse an W3C::SOAP::XSD::Document and create perl modul
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Parser version 0.02.
+This documentation refers to W3C::SOAP::XSD::Parser version 0.03.
 
 =head1 SYNOPSIS
 
@@ -455,6 +461,10 @@ the XSDs in the documents.
 
 Write the template to disk
 
+=item C<written_modules ()>
+
+Returns a list of all XSD modules written by the parser.
+
 =item C<get_schemas ()>
 
 Gets a list of the schemas imported/included from the base XML Schema(s)
